Equivalents to magrittr's pipes, plus some additions :
The %S>% pipe is like %>% except it supports using !!! in any function.
The %L>% pipe is like %>% except it logs to the console the call and the execution time.
The %\*>>% family of pipes contains equivalent that go faster because they
don't support functional chains (. %>% foo() %>% bar() nor the compound pipe (%<>%).
lhs %<>% rhslhs %>% rhs
lhs %>>% rhs
lhs %T>% rhs
lhs %T>>% rhs
lhs %$% rhs
lhs %$>>% rhs
lhs %S>% rhs
lhs %S>>% rhs
lhs %L>% rhs
lhs %L>>% rhs
A value or a dot (.).
A function call using pipe semantics of the relevant pipe.